##  Overview
It is possible to extend the Data Model with an optional <Tech Platform> Fact Sheet. <Tech Platform> is a Fact Sheet that allows you to group <IT Components> into standardized platform offerings for applications (see Windows Client <Tech Platform> example below).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749955d7a4410149d65d25791a7c9d6_LowRes.png)
Tech Platforms can be used in the context of standards management (e.g. to reduce the numbers of used <IT Components>) and help with data quality maintenance.
Platform owners can define <Tech Platforms> to offer a standard set of IT Components to the application owners to help them build out their applications.
Read on to learn how to enable tech platforms.
